==> ncbi-igblast_1.19.0.orig.tar.gz: ncbi-igblast-1.19.0-src/c++/include/objtools/pubseq_gateway/impl/cassandra/blob_task/insert_extended.hpp <==
#ifndef OBJTOOLS__PUBSEQ_GATEWAY__CASSANDRA__BLOB_TASK__INSERT_EXTENDED_HPP
#define OBJTOOLS__PUBSEQ_GATEWAY__CASSANDRA__BLOB_TASK__INSERT_EXTENDED_HPP

/*  $Id: insert_extended.hpp 642742 2021-12-28 15:18:08Z fukanchi $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Authors: Dmitrii Saprykin
 *
 * File Description:
 *
 * Cassandra insert blob according to extended schema task.
 *
 */

#include <corelib/request_status.hpp>
#include <corelib/ncbidiag.hpp>

#include <objtools/pubseq_gateway/impl/cassandra/cass_blob_op.hpp>
#include <objtools/pubseq_gateway/impl/cassandra/IdCassScope.hpp>

BEGIN_IDBLOB_SCOPE
USING_NCBI_SCOPE;

class CCassBlobTaskInsertExtended
    : public CCassBlobWaiter
{
    enum EBlobInserterState {
        eInit = 0,
        eInsertChunks,
        eWaitingChunksInserted,
        eInsertProps,
        eWaitingPropsInserted,
        eDone = CCassBlobWaiter::eDone,
        eError = CCassBlobWaiter::eError
    };

public:
    NCBI_DEPRECATED CCassBlobTaskInsertExtended(
        unsigned int op_timeout_ms,
        shared_ptr<CCassConnection>  conn,
        const string & keyspace,
        CBlobRecord * blob,
        bool async,
        unsigned int max_retries,
        TDataErrorCallback data_error_cb
    );

    CCassBlobTaskInsertExtended(
        shared_ptr<CCassConnection> conn,
        const string & keyspace,
        CBlobRecord * blob,
        bool async,
        TDataErrorCallback data_error_cb
    );

protected:
    virtual void Wait1() override;

private:
    CBlobRecord * m_Blob{nullptr};
};

END_IDBLOB_SCOPE

#endif

==> ncbi-igblast_1.20.0.orig.tar.gz: ncbi-igblast-1.20.0-src/c++/include/objtools/pubseq_gateway/impl/cassandra/blob_task/insert_extended.hpp <==
#ifndef OBJTOOLS__PUBSEQ_GATEWAY__CASSANDRA__BLOB_TASK__INSERT_EXTENDED_HPP
#define OBJTOOLS__PUBSEQ_GATEWAY__CASSANDRA__BLOB_TASK__INSERT_EXTENDED_HPP

/*  $Id: insert_extended.hpp 651942 2022-06-28 14:10:54Z saprykin $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Authors: Dmitrii Saprykin
 *
 * File Description:
 *
 * Cassandra insert blob according to extended schema task.
 *
 */

#include <corelib/request_status.hpp>
#include <corelib/ncbidiag.hpp>

#include <objtools/pubseq_gateway/impl/cassandra/cass_blob_op.hpp>
#include <objtools/pubseq_gateway/impl/cassandra/IdCassScope.hpp>

BEGIN_IDBLOB_SCOPE
USING_NCBI_SCOPE;

class CCassBlobTaskInsertExtended
    : public CCassBlobWaiter
{
    enum EBlobInserterState {
        eInit = 0,
        eInsertChunks,
        eWaitingChunksInserted,
        eInsertProps,
        eWaitingPropsInserted,
        eDone = CCassBlobWaiter::eDone,
        eError = CCassBlobWaiter::eError
    };

public:
    CCassBlobTaskInsertExtended(
        shared_ptr<CCassConnection> conn,
        const string & keyspace,
        CBlobRecord * blob,
        bool async,
        TDataErrorCallback data_error_cb
    );

protected:
    void Wait1() override;

private:
    CBlobRecord * m_Blob{nullptr};
};

END_IDBLOB_SCOPE

#endif
